/*
  basket.c
  cgi-util demo store
  add an item to your shopping basket, or just show them
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <unistd.h>
#include <cgi-util.h>
#include "tsv.h"


#define MAX_ITEMS 500


/* --- MAIN --- */

int main(int argc, char * argv[])
{
  FILE * fi;
  int num_items, i;
  item_type * items[MAX_ITEMS];
  const char * product_id, * session_id;
  char pid[16], filename[64], temp[64];
  float total;
  

  /* Init CGI: */
  
  cgi_init();
  printf("Content-type: text/html\n");


  /* Check for a session id cookie - if none, create one! */
  
  session_id = cgi_getcookie("session_id");
  
  if (session_id == NULL)
    {
      snprintf(pid, sizeof(pid), "%d", getpid());
      session_id = strdup(pid);
      
      printf("Set-Cookie: session_id=%s;\n",
	     session_id);
    }

  snprintf(filename, sizeof(filename), "sessions/%s", session_id);
  
  
  /* End HTML header and display top of page: */
  
  printf("\n");
  cgi_dump("top.html");
  
  
  /* Get product to add: */
  
  product_id = cgi_getentrystr("product_id");
  
  if (product_id != NULL && strlen(product_id) != 0)
    {
      /* Add the product to this user's session: */
      
      fi = fopen(filename, "a");
      if (fi == NULL)
	cgi_error("Can't add item to your basket!");
      
      fprintf(fi, "%s\n", product_id);
      
      fclose(fi);
    }
  
  
  /* Load all items so we can refer to them: */
  
  num_items = 0;
  
  fi = open_item_file("items.tsv");
  
  do
    {
      items[num_items++] = read_next_item(fi);
    }
  while (items[num_items - 1] != NULL && num_items < MAX_ITEMS - 1);

  num_items--;
  
  fclose(fi);
  
  
  /* Load the user's session and display all items: */
  
  fi = fopen(filename, "r");
  if (fi == NULL)
    cgi_error("Can't load your basket's contents!");
  
  total = 0.0;
  
  do
    {
      fgets(temp, sizeof(temp), fi);
      
      if (!feof(fi))
	{
	  temp[strlen(temp) - 1] = '\0';
	  
	  
	  /* Display the corresponding item: */
	  
	  for (i = 0; i < num_items; i++)
	    {
	      if (strcmp((items[i])->product_id, temp) == 0)
		{
		  printf("%s - %s - $%.2f<br>\n",
			 items[i]->product_id,
			 items[i]->title,
			 items[i]->price);
		  
		  total = total + items[i]->price;
		}
	    }
	}
    }
  while (!feof(fi));
  
  fclose(fi);
  
  
  printf("<hr size=1 noshade>\n");
  printf("Total: <b>$%.2f</b><p>\n", total);
  
  
  /* Close up and quit: */
  
  cgi_dump("bottom.html");
  cgi_quit();
  return(0);
}
